@@ -73,6 +73,9 @@ def create_scaffold(project_name):
     create_folder(os.path.join(project_name, "reports"))
     create_folder(os.path.join(project_name, "samples"))
     create_file(os.path.join(project_name, "samples", "__init__.py"))
+    create_folder(os.path.join(project_name, "samples", "assert"))
+    create_file(os.path.join(project_name, "samples", "assert", "__init__.py"))
+    create_file(os.path.join(project_name, "samples", "assert", "test_assert.py"), test_assert)
     create_folder(os.path.join(project_name, "samples", "db"))
     create_file(os.path.join(project_name, "samples", "db", "__init__.py"))
     create_file(os.path.join(project_name, "samples", "db", "test_mysql.py"), test_mysql_content)
